.. py:module:: PIL.ImagePalette
.. py:currentmodule:: PIL.ImagePalette

:py:mod:`~PIL.ImagePalette` Module
==================================

The :py:mod:`~PIL.ImagePalette` module contains a class of the same name to
represent the color palette of palette mapped images.

.. note::

    This module was never well-documented. It hasn't changed since 2001,
    though, so it's probably safe for you to read the source code and puzzle
    out the internals if you need to.

    The :py:class:`~PIL.ImagePalette.ImagePalette` class has several methods,
    but they are all marked as "experimental." Read that as you will. The
    ``[source]`` link is there for a reason.

.. autoclass:: PIL.ImagePalette.ImagePalette
    :members:
